@@ -4,11 +4,11 @@ export LC_ALL=C.UTF-8
 mkdir -p build && cd build
 rm * -rf
 meson .. \
-    -Denable-vala=true \
-    -Denable-print-profiles=false \
-    -Denable-argyllcms-sensor=false \
-    -Denable-sane=true \
-    -Denable-libcolordcompat=true $@
+    -Dvapi=true \
+    -Dprint_profiles=false \
+    -Dargyllcms_sensor=false \
+    -Dsane=true \
+    -Dlibcolordcompat=true $@
 ninja -v || bash
 ninja test -v
 DESTDIR=/tmp/install-ninja ninja install
