@@ -697,11 +697,9 @@ cd_client_create_profile (CdClient *client,
 	    g_hash_table_size (properties) > 0) {
 		list = g_hash_table_get_keys (properties);
 		for (l = list; l != NULL; l = l->next) {
-			g_variant_builder_add (&builder,
-					       "{ss}",
-					       l->data,
-					       g_hash_table_lookup (properties,
-								    l->data));
+			const gchar *key = l->data;
+			const gchar *value = g_hash_table_lookup (properties, key);
+			g_variant_builder_add (&builder, "{ss}", key, value);
 		}
 		g_list_free (list);
 	} else {
@@ -884,6 +882,7 @@ cd_client_import_mkdir_and_copy (GFile *source,
 }
 
 typedef struct {
+	CdClient		*client;
 	GFile			*dest;
 	GFile			*file;
 	guint			 hangcheck_id;
@@ -916,8 +915,10 @@ cd_client_import_task_data_free (CdClientImportTaskData *tdata)
 {
 	g_object_unref (tdata->file);
 	g_object_unref (tdata->dest);
-//	if (tdata->profile_added_id > 0)
-//		g_signal_handler_disconnect (tdata->client, tdata->profile_added_id);
+	if (tdata->profile_added_id > 0)
+		g_signal_handler_disconnect (tdata->client, tdata->profile_added_id);
+	if (tdata->client != NULL)
+		g_object_unref (tdata->client);
 	if (tdata->hangcheck_id > 0)
 		g_source_remove (tdata->hangcheck_id);
 	g_free (tdata);
@@ -986,6 +987,7 @@ cd_client_import_profile_find_filename_cb (GObject *source_object,
 
 	/* watch for a new profile to be detected and added,
 	 * but time out after a couple of seconds */
+	tdata->client = g_object_ref(client);
 	tdata->hangcheck_id = g_timeout_add (CD_CLIENT_IMPORT_DAEMON_TIMEOUT,
 					     cd_client_import_hangcheck_cb,
 					     task);
