@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2013 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2020 NVIDIA CORPORATION
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -35,22 +36,11 @@
 
 G_BEGIN_DECLS
 
-#define CD_TYPE_ICC		(cd_icc_get_type ())
-#define CD_ICC(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), CD_TYPE_ICC, CdIcc))
-#define CD_ICC_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), CD_TYPE_ICC, CdIccClass))
-#define CD_IS_ICC(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), CD_TYPE_ICC))
-#define CD_IS_ICC_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), CD_TYPE_ICC))
-#define CD_ICC_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), CD_TYPE_ICC, CdIccClass))
 #define CD_ICC_ERROR		(cd_icc_error_quark ())
 #define CD_ICC_TYPE_ERROR	(cd_icc_error_get_type ())
 
-typedef struct _CdIccPrivate CdIccPrivate;
-
-typedef struct
-{
-	 GObject		 parent;
-	 CdIccPrivate		*priv;
-} CdIcc;
+#define CD_TYPE_ICC (cd_icc_get_type ())
+G_DECLARE_DERIVABLE_TYPE (CdIcc, cd_icc, CD, ICC, GObject)
 
 /**
  * CdIccError:
@@ -80,7 +70,7 @@ typedef enum {
 	CD_ICC_ERROR_LAST
 } CdIccError;
 
-typedef struct
+struct _CdIccClass
 {
 	GObjectClass		 parent_class;
 	/*< private >*/
@@ -93,7 +83,7 @@ typedef struct
 	void (*_cd_icc_reserved6) (void);
 	void (*_cd_icc_reserved7) (void);
 	void (*_cd_icc_reserved8) (void);
-} CdIccClass;
+};
 
 /**
  * CdIccLoadFlags:
@@ -138,7 +128,6 @@ typedef enum {
 	CD_ICC_SAVE_FLAGS_LAST
 } CdIccSaveFlags;
 
-GType		 cd_icc_get_type			(void);
 GQuark		 cd_icc_error_quark			(void);
 CdIcc		*cd_icc_new				(void);
 
@@ -207,6 +196,8 @@ void		 cd_icc_remove_metadata			(CdIcc		*icc,
 GPtrArray	*cd_icc_get_named_colors		(CdIcc		*icc);
 gboolean	 cd_icc_get_can_delete			(CdIcc		*icc);
 GDateTime	*cd_icc_get_created			(CdIcc		*icc);
+void		 cd_icc_set_created			(CdIcc		*icc,
+							 GDateTime	*creation_time);
 const gchar	*cd_icc_get_checksum			(CdIcc		*icc);
 const gchar	*cd_icc_get_description			(CdIcc		*icc,
 							 const gchar	*locale,
@@ -265,6 +256,10 @@ gboolean	 cd_icc_create_from_edid_data		(CdIcc		*icc,
 gboolean	 cd_icc_create_default			(CdIcc		*icc,
 							 GError		**error)
 							 G_GNUC_WARN_UNUSED_RESULT;
+gboolean	 cd_icc_create_default_full		(CdIcc		*icc,
+							 CdIccLoadFlags	 flags,
+							 GError		**error)
+							 G_GNUC_WARN_UNUSED_RESULT;
 GPtrArray	*cd_icc_get_vcgt			(CdIcc		*icc,
 							 guint		 size,
 							 GError		**error)
